# This specfile is licensed under:
# SPDX-License-Identifier: MIT
# License text: https://spdx.org/licenses/MIT.html
# SPDX-FileCopyrightText: 2022 Maxwell G <gotmax@e.email>
# SPDX-FileCopyrightText: Fedora Project Authors

# Pagure does not support downloading raw files of tags.
# Referencing the commit hash is necessary
%dnl %global upstream_version 3.2.0
%global upstream_version c32fbbd25bbcedee8c0b898d3653255b18a0d30e

Name:           go-rpm-macros-epel
Version:        1
Release:        8%{?dist}
Summary:        Backport of certain Fedora Go RPM macros to EPEL

License:        GPL-3.0-or-later
URL:            https://pagure.io/go-rpm-macros
Source:         macros.zzz-go-rpm-macros-epel
Source:         macros.zzz-go-srpm-macros-epel
Source:         https://pagure.io/go-rpm-macros/raw/%{upstream_version}/f/rpm/go_mod_vendor.prov
Source:         https://pagure.io/go-rpm-macros/raw/%{upstream_version}/f/rpm/fileattrs/go_mod_vendor.attr

# Upstream go-rpm-macros README
Source:         https://pagure.io/go-rpm-macros/raw/%{upstream_version}/f/README.md#/README.upstream.md
# README specific to the backports in this package.
Source:         README.md
Source:         https://pagure.io/go-rpm-macros/raw/%{upstream_version}/f/LICENSE.txt
# golist-symlink subpackage license
Source:         https://github.com/spdx/license-list-data/raw/master/text/Unlicense.txt

# Require RHEL's macros. We BuildRequire the macros to make sure they still
# install and to allow us run testing in %check if we decide to later.
BuildRequires:  go-rpm-macros
Requires:       go-rpm-macros

Requires:       go-srpm-macros-epel = %{version}-%{release}
Requires:       /usr/bin/golist

%description
go-rpm-macros-epel contains backports of certain Go RPM macros from Fedora.


%package -n     go-srpm-macros-epel
Summary:        Backport of certain Go SRPM macros from Fedora
BuildArch:      noarch
# Explicitly Require go-srpm-macros from RHEL even though they are already part
# of the buildroot. We import its Lua.
BuildRequires:  go-srpm-macros
Requires:       go-srpm-macros
# Pull in go-rpm-macros-epel if go-rpm-macros is installed.
Requires:       (go-rpm-macros-epel if go-rpm-macros)

%description -n go-srpm-macros-epel
go-srpm-macros-epel contains backports of certain Go SRPM macros from Fedora.


%package -n     go-rpm-macros-golist-symlink
Summary:        Provides symlink to the bundled golist in go-rpm-macros
# The package just provides a symlink.
License:        Unlicense
# Conflict with standard golist in case that gets packaged.
Conflicts:      golist
Requires:       go-rpm-macros

%description    -n go-rpm-macros-golist-symlink
go-rpm-macros-golist-symlink provides a symlink from /usr/bin to
go-rpm-macros's bundled golist, which is installed in
/usr/libexec/go-rpm-macros. This allows the macros that expect to find golist
in $PATH to work properly.

This package is split out and namespaced to allow the upstream golist to be
packaged as golist.


%prep
cp -a %{sources} .


%install
# Install macros and lua
install -Dpm 0644 macros.* -t %{buildroot}%{_rpmmacrodir}

# Install go_mod_vendor generator
install -Dpm 0644 go_mod_vendor.attr -t %{buildroot}%{_rpmconfigdir}/fileattrs
install -Dpm 0755 go_mod_vendor.prov -t %{buildroot}%{_rpmconfigdir}

# Create symlink for golist-symlink subpackage
mkdir %{buildroot}%{_bindir}
ln -s %{_libexecdir}/go-rpm-macros/golist %{buildroot}%{_bindir}/golist

# Install REAMDE and licenses to a single directory for both subpackages.
install -Dpm 0644 README.md README.upstream.md \
    -t %{buildroot}%{_docdir}/go-rpm-macros-epel
install -Dpm 0644 LICENSE.txt \
    -t %{buildroot}%{_defaultlicensedir}/go-rpm-macros-epel

%ifarch %{go_arches}
%files
%{_rpmmacrodir}/macros.zzz-go-rpm-macros-epel
%{_rpmconfigdir}/go_mod_vendor.prov
%{_rpmconfigdir}/fileattrs/go_mod_vendor.attr
%endif

%files -n       go-srpm-macros-epel
%license %{_defaultlicensedir}/go-rpm-macros-epel
%doc %{_docdir}/go-rpm-macros-epel
%{_rpmmacrodir}/macros.zzz-go-srpm-macros-epel

%files -n       go-rpm-macros-golist-symlink
%doc README.md
%license Unlicense.txt
%{_bindir}/golist


%changelog
* Thu Sep 08 2022 Maxwell G <gotmax@e.email> - 1-8
- go-srpm-macros: Explicitly Require go-srpm-macros from RHEL

* Thu Sep 08 2022 Maxwell G <gotmax@e.email> - 1-7
- Install docs into the correct directory

* Wed Sep 07 2022 Maxwell G <gotmax@e.email> - 1-6
- Move go_mod_vendor generator from -srpm-macros to -rpm-macros subpackage

* Sat Sep 03 2022 Maxwell G <gotmax@e.email> - 1-5
- Fix %%goinstall flags definition
- go-srpm-macros-epel: Pull in go-rpm-macros-epel if go-rpm-macros is installed.

* Wed Aug 31 2022 Maxwell G <gotmax@e.email> - 1-4
- Redfine %%goinstallflags
  Relates: rhbz#2098400
- Add support for `%%golang_arches_future` and `%%gometa -f`.
  Relates: rhbz#2121796
- Add go-rpm-macros-golist-symlink
  Relates: rhbz#2100618

